@@ -7,16 +7,19 @@
 """Print the table of historical DUT1 values"""
 from datetime import timedelta
 from itertools import groupby
+import wwvb
 from .iersdata import DUT1_DATA_START, DUT1_OFFSETS
 
 
 def main():
     """Print the table of historical DUT1 values"""
-    date = DUT1_DATA_START.date()
+    date = DUT1_DATA_START
     for key, it in groupby(DUT1_OFFSETS):
         dut1_ms = (ord(key) - ord("k")) / 10.0
         count = len(list(it))
-        print("%10s % 3.1f %4d" % (date, dut1_ms, count))
+        dut1_next = wwvb.get_dut1(date + timedelta(days=count))
+        ls = " LS" if dut1_ms * dut1_next < 0 else ""
+        print("%10s % 3.1f %4d%s" % (date, dut1_ms, count, ls))
         date += timedelta(days=count)
     print(date)
 
